diff --git a/CMakeLists.txt b/CMakeLists.txt
index fea7a6b8f88ff46894ae742808e5e2ec75d15aa0..0f8894a33cbe0c30491afeba501c603c4f748b09 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -232,7 +232,7 @@ else()
   set (PNG_LIBRARY "")
 endif()
 
-find_package(Eigen 2.0.0 REQUIRED)
+find_package(Eigen 3.2.0 REQUIRED)
 find_package(Python 2.4 REQUIRED)
 
 if(USE_NUMPY)
@@ -299,7 +299,7 @@ endif()
 # basic environment
 include_directories(${Boost_INCLUDE_DIRS} 
                     ${FFTW_INCLUDE_DIRS} 
-                    ${EIGEN2_INCLUDE_DIRS}
+                    ${EIGEN3_INCLUDE_DIRS}
                     ${TIFF_INCLUDE_DIR}
                     ${PNG_INCLUDE_DIRS}
                     ${OPEN_MM_INCLUDE_DIRS}
diff --git a/modules/doc/install.rst b/modules/doc/install.rst
index a0b36a3f12cfc3a305e8b5e553f16bdc824e07c8..526bb1fda63839c4a59af89b8c1444044bbfd498 100644
--- a/modules/doc/install.rst
+++ b/modules/doc/install.rst
@@ -28,7 +28,7 @@ Installing the Dependencies
 OpenStructure uses a bunch of OpenSource libraries. If you haven't already installed them, please install them now! Where appropriate the minimally required version is given in parantheses.
 
  * `CMake <http://cmake.org>`_ (2.6.4)
- * `Eigen2 <http://eigen.tuxfamily.org>`_ (2.0.6)
+ * `Eigen3 <http://eigen.tuxfamily.org>`_ (3.2.0)
  * `Boost <http://boost.org>`_ (1.47)
  * `libpng <http://www.libpng.org>`_ 
  * `Python <http://python.org>`_ (2.7)
diff --git a/cmake_support/FindEigen.cmake b/cmake_support/FindEigen.cmake
index fe8937b0203800bd02490febe517aa0ba164d98b..36e33176aea2c6592cf9c02dc9c9612900ad82de 100644
--- a/cmake_support/FindEigen.cmake
+++ b/cmake_support/FindEigen.cmake
@@ -1,20 +1,19 @@
-# - Try to find Eigen2 lib
+# - Try to find Eigen3 lib
 # Once done this will define
 #
 #  EIGEN2_FOUND - system has eigen lib
 #  EIGEN2_INCLUDE_DIRS - the eigen include directories
 
-find_path(EIGEN2_INCLUDE_DIR NAMES Eigen/Core
-          PATH_SUFFIXES eigen2
-          PATH_SUFFIXES eigen3
+find_path(EIGEN3_INCLUDE_DIR NAMES Eigen/Core
+PATH_SUFFIXES eigen3
 )
 
-set(EIGEN2_INCLUDE_DIRS ${EIGEN2_INCLUDE_DIR}) 
+set(EIGEN3_INCLUDE_DIRS ${EIGEN3_INCLUDE_DIR}) 
 
 include (FindPackageHandleStandardArgs)
-find_package_handle_standard_args (EIGEN DEFAULT_MSG EIGEN2_INCLUDE_DIR)
+find_package_handle_standard_args (EIGEN DEFAULT_MSG EIGEN3_INCLUDE_DIR)
 
-mark_as_advanced (EIGEN2_INCLUDE_DIR)
+mark_as_advanced (EIGEN3_INCLUDE_DIR)
 
 
 
@@ -1,20 +1,19 @@
 # Once done this will define
 #
-#  EIGEN2_FOUND - system has eigen lib
-#  EIGEN2_INCLUDE_DIRS - the eigen include directories
+#  EIGEN3_FOUND - system has eigen lib
+#  EIGEN3_INCLUDE_DIRS - the eigen include directories
 